<?php
/*
Plugin Name: Depo.sk
Plugin URI: http://depo.sk
Description: Prepavná metóda pre depo.sk
Version: 1.3
Author: viktor@oktodigital.com
Author URI: https://oktodigital.com
*/

/**
 * Check if WooCommerce is active
 */

if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

	define( 'OKTO_DEPO_REQUIRED_PHP_VERSION', '5.3' );                          // because of get_called_class()
	define( 'OKTO_DEPO_REQUIRED_WP_VERSION',  '3.1' );                          // because of esc_textarea()
	define( 'OKTO_DEPO_REQUIRED_WC_VERSION',  '2.6.8' );                        // TODO

	define( 'OKTO_DEPO_PATH',         	      plugin_dir_path(__FILE__) );
	define( 'OKTO_DEPO_INC_PATH',         	  OKTO_DEPO_PATH . 'inc' . DIRECTORY_SEPARATOR );
	define( 'OKTO_DEPO_URL',   		      	  plugins_url( '', __FILE__ ) . '/' );
	define( 'OKTO_DEPO_DEBUG',         	      'debug.log' );
	define( 'OKTO_DEPO_PREFIX',         	  'depo_sk_' );

	require_once(  OKTO_DEPO_INC_PATH . 'depo-api.php' );
	require_once(  OKTO_DEPO_INC_PATH . 'functions.php' );

	class depo_shipping_method_setup {

		use Functions;

		public $payment_gateways;
		public $config;
		public $api;

		public function __construct() {

			$this->config   = include( OKTO_DEPO_INC_PATH . 'config.php' );

			$this->id       = $this->config['id']; //'depo_shipping_method';
			$this->bulk_id  = $this->config['bulk_id']; // 'depo_bulk_print';

			$this->method_title       = $this->config['method_title']; // __( 'Depo.sk' );  // Title shown in admin
			$this->method_description = $this->config['method_description']; // __( 'Prepavná metóda pre depo.sk' ); // Description shown in admin

			$this->settings = get_option('woocommerce_'.$this->id.'_settings'); // hlavne nastavenia

			add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), array( $this, 'plugin_add_settings_link') );
			add_action( 'admin_menu', array( $this, 'plugin_admin_add_page') ); // add custom page
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts') ); // admin skripty
			register_uninstall_hook(__FILE__, array( 'depo_shipping_method_setup', 'uninstall') );

			// pridanie tabu do admin - produkt
			add_filter( 'woocommerce_product_data_tabs', array( $this, 'add_okto_depo_method_tab') , 99 , 1 );
			add_action( 'woocommerce_product_data_panels', array( $this, 'add_okto_depo_method_fields') );
			
			// admin stuff
			add_action( 'woocommerce_process_product_meta', array( $this, 'custom_product_fields_save') ); // custom polozky ulozit zmeny on save
			add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes') );
			
			add_action( 'woocommerce_shipping_init', array($this, 'depo_shipping_method_init') ); // basic 
			add_filter( 'woocommerce_shipping_methods', array( $this, 'add_depo_shipping_method') ); // basic 
			add_filter( 'woocommerce_package_rates', array( $this, 'hide_shipping'), 100 );

			if ( $errors = $this->requirements() ) {
				add_action( 'admin_notices', array( $this, 'requirements_error') );
				return;
			}
			
			// formality
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts') ); // skripty

			// bulk label print
			add_action( 'admin_footer-edit.php', array( $this, 'custom_bulk_admin_footer') ); // bulk TODO

			$this->payment_gateways = [];

			$this->api = $this->canInitDepoClass() ? new Depo( $this->settings ) : false;

			// injecty
			add_action( 'admin_init', array( $this, 'label_print') ); // tlac stitku, musi byt v init lebo nastavuje headre
			add_action( 'woocommerce_checkout_process', array( $this, 'on_order_validation') ); // on order validation 
			add_action( 'woocommerce_after_shipping_rate', array( $this, 'inject_iframe') ); // display after shipping label
			add_action( 'woocommerce_checkout_update_order_meta', array( $this, 'on_save') ); // after placing order
		}

		public function hide_shipping( $rates ) {
			if(!$this->requirements()) return $rates;
			$filter = array();
			foreach ( $rates as $rate_id => $rate ) {
				if ( $this->id === $rate->method_id ) continue;
				$filter[ $rate_id ] = $rate;
			}
			return $filter;
		}

		public function plugin_add_settings_link( $links ) {
		    $settings_link = '<a href="'.admin_url( 'admin.php?page=wc-settings&tab=shipping&section=' . $this->id ).'">' . __( 'Settings' ) . '</a>';
		    $links[] = $settings_link;

		    $settings_link = '<a target="_blank" href="'.plugins_url( 'docu/', __FILE__ ).'">' . __( 'Documentation' ) . '</a>';
		    $links[] = $settings_link;
		  	
		  	return $links;
		}	

		public static function uninstall() {
			$config = include( OKTO_DEPO_INC_PATH . 'config.php' );
			delete_option('woocommerce_'.$config['id'].'_settings');
		}

		public function requirements() {
			global $wp_version;

			$return = false;

			if ( version_compare( PHP_VERSION, OKTO_DEPO_REQUIRED_PHP_VERSION, '<' ) ) {
				$return[] = sprintf( __( 'PHP verzia %s (Vaša %s)' , 'depo-sk'), OKTO_DEPO_REQUIRED_PHP_VERSION, PHP_VERSION );
			}

			if ( version_compare( $wp_version, OKTO_DEPO_REQUIRED_WP_VERSION, '<' ) ) {
				$return[] = sprintf( __( 'WordPress verzia %s (Vaša %s)' , 'depo-sk'), OKTO_DEPO_WP_VERSION, $wp_version );
			}

			if ( !in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
				$return[] = __( 'Woocommerce - aktivovaný plugin' , 'depo-sk');
			}

			if ( !$this->canInitDepoClass() ) {
				$return[] = '<a href="'.admin_url().'admin.php?page=wc-settings&tab=shipping&section='.$this->id.'">' . __( 'Depo.sk nastavenia (ID,email,heslo)' , 'depo-sk') . '</a>';
			}

			return $return;
		}
		
		function requirements_error() {
			global $wp_version;
			?>
				<div class="error">
					<p><?php echo sprintf( __('%s: pre správne fungovanie je potrebné vyriešiť tieto nastavenia:') , $this->method_title ); ?></p>

					<ul class="ul-disc">
						<?php foreach($this->requirements() as $error) : ?>
							<li>
								<?php echo $error; ?>
							</li>
						<?php endforeach; ?>
					</ul>
				</div>
			<?php
		}

		public function add_okto_depo_method_tab( $product_data_tabs ) {
		    $product_data_tabs[$this->id] = array(
				'label'  => $this->config['method_title'],
				'target' => $this->id . '_panel',
				'class'  => [],
		    );
		    return $product_data_tabs;
		}

		public function add_okto_depo_method_fields() {
		    ?>
		    <!-- id below must match target registered in above add_okto_depo_method_tab function -->
		    <div id="<?php echo $this->id . '_panel'; ?>" class="panel woocommerce_options_panel">
		        <?php
		        woocommerce_wp_checkbox( array( 
							'id'            => '_depo_18years_check', 
							'wrapper_class' => '', 
							'label'         => __('Musí mať 18 rokov', 'depo-sk'), 
							'description'   => __('Pri prevzatí zásielky overiť či kupujúci dovŕšil 18 rokov.', 'depo-sk') 
							) );
		        ?>
		    </div>
		    <?php
		}

		public function label_print() {

			// temp fix
			// $payments = WC()->payment_gateways->get_available_payment_gateways();
			$this->payment_gateways = $this->set_payment_gateways();


			// https://make.wordpress.org/core/2016/10/04/custom-bulk-actions/
			// bulk
			// if(isset($_REQUEST['post']) and (( isset($_GET['action']) and $_GET['action'] == $this->bulk_id) or ( isset($_GET['action2']) and $_GET['action2'] == $this->bulk_id)) ) {
			// 	$orderids = array_map('intval', $_REQUEST['post']);
			// 	$print_ids = [];

			// 	foreach($orderids as $id) {
			// 		$order = unserialize( get_post_meta( $id, '_okto-depo-order', true ) );
			// 		if(isset($order->number))
			// 			$print_ids[] = $order->number;
			// 	}

			// 	if(empty( $print_ids )) return;
				
			// 	$print = $this->api->label( join(',', $print_ids) );
			// 	var_dump($print);
			// 	return;
			// }

			$print_id_by_post = ( isset($_GET['page']) and $_GET['page'] == $this->id and isset($_GET['print_post_id']) and $_GET['print_post_id'] != '' ) ? $_GET['print_post_id'] : false;

			if($print_id_by_post) {
				$okto_depo_order = unserialize( get_post_meta( $print_id_by_post, '_okto-depo-order', true ) );
				if(!isset($okto_depo_order->number)) return;
				$out = $this->api->label($okto_depo_order->number);
				$this->print_label($out, $print_id_by_post . '-' . $okto_depo_order->number);
			}

			$print_id = ( isset($_GET['page']) and $_GET['page'] == $this->id and isset($_GET['print_id']) and $_GET['print_id'] != '' ) ? $_GET['print_id'] : false;

			if($print_id) {
				$post_id = (isset($_GET['post_id']) and $_GET['post_id'] != '') ? $_GET['post_id'] : ''; 
				$out = $this->api->label($print_id);
				$this->print_label($out, $post_id . '-' . $print_id);
			}
		}

		public function plugin_options_page() {

			// cislo objednavky vo WP
			$order_id  = ( isset($_GET['order_id']) and $_GET['order_id'] != '' ) ? $_GET['order_id'] : false;

			$edit = ( isset($_GET['depo_id']) and $_GET['depo_id'] != '' and
					  isset($_GET['pickup']) and $_GET['pickup'] != '' );

			if($edit and $order_id) {
				$cancel = $this->api->cancel($_GET['depo_id']);
				$depo18 = (isset($_GET['depo18']) and $_GET['depo18'] == 'true') ? true : false ;
				$cod    = (isset($_GET['cod']) and $_GET['cod'] == 'true') ? true : false ;
				$result = $this->api->send($order_id, $_GET['pickup'], $depo18, $cod);

				if(isset($result->number)) {
					$address = $this->api->place( $_GET['pickup'] );
					update_post_meta( $order_id, '_okto-depo-address', serialize( $address ) ); // save vydajne miesto
			        update_post_meta( $order_id, '_okto-depo-order', serialize( $result ) );
			        update_post_meta( $order_id, '_depo_18years_check', $depo18 ? 'yes' : 'no' );
			        update_post_meta( $order_id, '_depo_cod', $cod ? 'yes' : 'no' );
				?>
					<div class="updated notice">
					    <p><?php _e('Registrácia balíku úspešná', 'depo-sk'); ?></p>
					</div>
				<?php
				} else {
				?>
					<div class="error notice">
					    <p><?php _e('Nepodarilo sa registrovať balík', 'depo-sk'); ?></p>
					</div>
				<?php
				}

			}

			// zrusit objednavku
			$cancel_id = ( isset($_GET['cancel_id']) and $_GET['cancel_id'] != '' ) ? $_GET['cancel_id'] : false;
			if($cancel_id and $order_id) {
				if($this->api->cancel($cancel_id)) {
					$data = new stdClass();//create a new 
					$data->detail = __('Zásielka zrušená', 'depo-sk');
					update_post_meta( $order_id, '_okto-depo-order', serialize( $data ) );
				?>
					<div class="updated notice">
					    <p><?php _e('Preprava balíku zrušená', 'depo-sk'); ?></p>
					</div>
				<?php
				} else {
				?>
					<div class="error notice">
					    <p><?php _e('Preprava balíku už bola zrušená alebo preprava neexistuje', 'depo-sk'); ?></p>
					</div>
				<?php
				}
			}

			// znova poslat failnutu objednavku
			$resend_address = ( isset($_GET['resend_address']) and $_GET['resend_address'] != '' ) ? $_GET['resend_address'] : false;
			if($resend_address and $order_id) {

				$result = $this->api->send($order_id, $resend_address);

				if(isset($result->number)) {
			        update_post_meta( $order_id, '_okto-depo-order', serialize( $result ) );
				?>
					<div class="updated notice">
					    <p><?php _e('Registrácia balíku úspešná', 'depo-sk'); ?></p>
					</div>
				<?php
				} else {
				?>
					<div class="error notice">
					    <p><?php _e('Nepodarilo sa registrovať balík', 'depo-sk'); ?></p>
					</div>
				<?php
				}
			}

			if(!$order_id) {
				printf( __( 'Všetky nastavenia pre depo.sk nájdete v sekcií %sWooCommerce->Nastavenia->Doprava->Depo.sk%s.', 'depo-sk' ), '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=shipping&section=' . $this->id ) . '">', '</a>' );
				return;
			}

			// redirect to product edit
			$admin_url = admin_url('post.php?post='.$order_id.'&action=edit');
			?>
			<script type="text/javascript">   
				function Redirect() {  
					window.location="<?php echo $admin_url; ?>"; 
				} 
				setTimeout('Redirect()', 10);   
			</script>
			<?php

		}

		public function plugin_admin_add_page() {

			$title = __('Depo.sk','depo-sk');
			add_options_page( $title, $title, 'manage_options', $this->id, array($this, 'plugin_options_page'));
		}

		public function custom_product_fields_save() {
			$post_id = $_POST['post_ID'];

			// Checkbox
			update_post_meta( $post_id, '_depo_18years_check', isset( $_POST['_depo_18years_check'] ) ? 'yes' : 'no' );
		}

		public function add_meta_boxes() {

			global $woocommerce, $order, $post;
			
			// fix for WC 3.0.X
			if(!isset($post->post_type) || $post->post_type != 'shop_order') {
				return;
			}

			$order = new WC_Order($post->ID);
			$shipping = $order->get_items( 'shipping' );
			$shipping = array_shift($shipping)['method_id'];

			if($this->strip_instance( $shipping ) != $this->id) return;

			add_meta_box( 'okto_depo_other_fields', __('Depo.sk','depo-sk'), array( $this, 'meta_box_container' ), 'shop_order', 'side', 'core' );
		}

		public function meta_box_container() {
			global $woocommerce, $post;

			$post_id         = $post->ID;
			$okto_depo_order = unserialize( get_post_meta( $post_id, '_okto-depo-order', true ) );
			$plugin_url      = admin_url( 'options-general.php?page=' . $this->id );
			$address         = get_post_meta( $post_id, '_okto-depo-address', true );
			$address         = unserialize( $address );
			$isOK            = (isset($okto_depo_order->number)) ? true : false;

			echo '<ul class="order_actions submitbox okto_depo_toggle_edit">';

			if( $isOK ) {
				echo '<li class="wide"><strong>' . __( 'ID objednávky: ', 'depo-sk') . $okto_depo_order->number . '</strong> <span title="'.__( 'Odhadovaná cena za službu', 'depo-sk').'">(' . $okto_depo_order->price . '&euro;)</span></li>';
			} else {
				echo '<li class="wide"><strong style="background: #ffa3a3">' . __( 'Chyba objednávky', 'depo-sk') . '</strong></li>';
				if(isset($okto_depo_order->detail))
					echo '<li class="wide"><span style="border-bottom: 1px dashed #777;
				cursor: help;" title=" ' . print_r($okto_depo_order, true) . ' ">(' . $okto_depo_order->detail . ')</span></li>';
			}

			echo '<li class="wide "><strong>' . __( 'Výdajné miesto: ', 'depo-sk' ) . '</strong>';

			if(isset($address->id))
				echo '<strong>' . $address->id . '</strong>';

			$flags             = [];
			$post_meta         = get_post_meta( $post_id );

			$flags['cod']      = ($post_meta['_depo_cod'][0] == 'yes');
			$flags['eighteen'] = ($post_meta['_depo_18years_check'][0] == 'yes');


			if( $flags['eighteen'] ) {
				echo '<span style="font-size: 11px;margin-left:5px;height: 14px;" title="' . __( 'Kontrola veku pri prevzatí', 'depo-sk') . '" >' . __( '18+', 'depo-sk') . '</span>';
			}

			if( $flags['cod'] ) {
				echo '<span style="font-size: 11px;margin-left:5px;height: 14px;" title="' . __( 'Platba pri prevzatí', 'depo-sk') . '" >' . __( 'COD', 'depo-sk') . '</span>';
			}

			if($isOK) {
				echo '<a class="okto_depo_edit_toggle_button" href="javascript:;" style="margin-left:5px;text-decoration:none;font-size: 12px;color: rgb(160, 160, 160);" name="edit" value="'.__('Upraviť', 'depo-sk').'"><span class="dashicons dashicons-edit"></span></a>';

			}

			echo '<br>';

			if(isset($address->name))
				echo $address->name;

			if(isset($address->zip))
				echo ', ' . $address->zip;

			if(isset($address->city))
            echo ', ' . $address->city; // . '<br>';

        echo '</li>';



        echo '<li class="wide ">';

        if($isOK) {
        	echo '<div id="delete-action"><a class="submitdelete deletion" onclick="return confirm(\''.__('Chcete zrušiť doručenie?', 'depo-sk').'\')" href="' . $plugin_url . '&cancel_id='.$okto_depo_order->number . '&order_id='.$post_id.'">' . __('Zrušiť', 'depo-sk') . '</a></div>';

        	echo '<a style="margin-left: 5px;" href="' . $plugin_url . '&print_id='.$okto_depo_order->number . '&post_id='.$post_id.'" class="button save_order button-primary" name="save" value="'.__('Tlačiť štítok', 'depo-sk').'">'.__('Tlačiť štítok', 'depo-sk').'</a>';

        } else {
        	echo '<a href="' . $plugin_url . '&order_id='.$post_id . '&resend_address='.$address->id.'" class="button save_order button-primary" name="save" value="'.__('Tlačiť štítok', 'depo-sk').'">'.__('Znova odoslať', 'depo-sk').'</a>';
        }

        echo '</li>';

        echo '</ul>';

        if($isOK) : ?>

			<div class="okto_depo_toggle_edit" style="display: none;">
				
					<input type="hidden" id="okto_depo_edit_order_id" name="order_id" value="<?php echo $post_id; ?>">
					<input type="hidden" id="okto_depo_edit_depo_id" name="depo_id" value="<?php echo $okto_depo_order->number; ?>">
				
					<?php echo $this->api->generate_dropdown_with_places( $address->city, $address->id ); ?>
					
					<label class="okto-depo-label">
						<span class="okto-depo-numbers">3.</span>
						<input type="checkbox" <?php if($flags['eighteen']) echo ' checked="checked" '; ?> id="okto_depo_edit_18" name="okto-depo-18"><?php _e( 'Kontrola veku pri prevzatí', 'depo-sk'); ?> 
					</label>			

					<label class="okto-depo-label">
						<span class="okto-depo-numbers">4.</span>
						<input type="checkbox" <?php if($flags['cod']) echo ' checked="checked" '; ?> id="okto_depo_edit_cod" name="okto-depo-cod"><?php _e( 'Platba pri prevzatí', 'depo-sk') ?> 
					</label>

					<ul class="order_actions submitbox">
						<li class="wide ">
							<div id="delete-action">
								<a class="submitdelete deletion okto_depo_edit_toggle_button" href="javascript:;"><?php _e('Späť', 'depo-sk'); ?></a>
							</div>
							<a href="<?php echo $plugin_url; ?>" style="margin-left: 5px;" class="button save_order button-primary" id="okto_depo_edit_url"><?php _e('Upraviť', 'depo-sk'); ?></a>
						</li>
					</ul>

			</div>

		<?php endif;

    }

    public function depo_shipping_method_init() {
    	include( OKTO_DEPO_INC_PATH . 'shipping_class.php');
    }

    public function add_depo_shipping_method( $methods ) {
    	$methods[$this->id] = $this->config['shipping_class'];
    	return $methods;
    }


    public function on_save( $order_id ) {

			$order_hash = $this->get_order_hash(); // iframe

			// select box
			$address    = (isset($_POST['okto-depo-pickup'])) ? $this->validate_selected_pickup( $_POST['okto-depo-pickup'] ) : false; 

			// iframe
			if(!$address) {

				$address = $this->api->selected( $order_hash );
				if($address->is_selected <> 1) {
					wc_add_notice( $message, 'error' );
				}

			}

			$result = $this->api->send( $order_id, $address->id );

			update_post_meta( $order_id, '_okto-depo-address', serialize( $address ) ); // save vydajne miesto
			update_post_meta( $order_id, '_okto-depo-order',   serialize( $result ) ); // save depo order number and price

			// clean
			$this->remove_order_hash();
		}



		public function inject_iframe( $methods ) {

			if(!is_checkout() or !$this->api) return;

			$chosen_shipping = WC()->session->get( 'chosen_shipping_methods' );
			$chosen_shipping = array_shift( $chosen_shipping );

			if($methods->method_id != 'depo_shipping_method' or $methods->id != $chosen_shipping) return;

			$iframe = $this->settings['checkout_use_iframe'];

			$html = '<div id="okto-depo-wrapper">';
			$html .= $this->api->show_dropdown_with_places(true, $iframe);

			if($iframe)
				$html .= $this->api->getIframe( $this->get_order_hash() );

			$html .= '<div>';

			echo $html;
		}



		public function on_order_validation() {

			$chosen_shipping = WC()->session->get( 'chosen_shipping_methods' );
			$chosen_shipping = $chosen_shipping[0];

			if($this->strip_instance( $chosen_shipping ) <> $this->id) return true; // no need for checking

			$message = __('Prosím vyberte si výdajné miesto pre dopravu depo.sk', 'depo-sk');
			$message = '<a href="#okto-depo-wrapper">' . $message . '</a>';

			// ak bol poslany ID place cez dropdown
			if(isset($_POST['okto-depo-pickup'])) {

				if($_POST['okto-depo-pickup'] != '' or $this->validate_selected_pickup( $_POST['okto-depo-pickup'] )) {
					return true; // vybrate a spravne
				}

				wc_add_notice( $message, 'error' );
				return false;
			}

			// iframe
			$response = $this->api->selected( $this->get_order_hash() );

			// chyba komunikacie s API
			if(isset($response->title)) {
				$message = sprintf( __( 'Chyba komunikácie s Depo.sk API: "%s"' , 'depo-sk'), $response->title );

				if(isset($response->detail)) 
					$message .= sprintf( __( ', (detail "%s")' , 'depo-sk'), $response->detail );

				wc_add_notice( $message, 'error' );
				return;
			}

			// NOT SELECTED 
			if($response->is_selected <> 1)
				wc_add_notice( $message, 'error' );

		}

		public function admin_enqueue_scripts() {

			wp_register_script( 'jquery.chained', plugins_url( 'js/jquery.chained.min.js', __FILE__ ), array( 'jquery' ), 1, true );
			wp_register_script( OKTO_DEPO_PREFIX . 'js_admin', plugins_url( 'js/admin.js', __FILE__ ), array( 'jquery' ), 1.92, true );

			wp_register_style(
				OKTO_DEPO_PREFIX . 'css_admin',
				plugins_url( 'css/admin.css', __FILE__ ),
				array(),
				1.92,
				'all'
				);

			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'jquery.chained' );
			wp_enqueue_script( OKTO_DEPO_PREFIX . 'js_admin' );
			wp_enqueue_style(  OKTO_DEPO_PREFIX . 'css_admin' );

		}

		public function enqueue_scripts() {

			if(!is_checkout()) return;

			$data = array(
			    'checkout_width_edit' => (int)$this->settings['checkout_width_edit']
			);

			wp_register_script( 'jquery.chained', plugins_url( 'js/jquery.chained.min.js', __FILE__ ), array( 'jquery' ), 1, true );
			wp_register_script( OKTO_DEPO_PREFIX . 'main', plugins_url( 'js/main.js', __FILE__ ), array( 'jquery' ), 1.2, true );

			wp_register_style(
				OKTO_DEPO_PREFIX . 'main',
				plugins_url( 'css/main.css', __FILE__ ),
				array(),
				1.2,
				'all'
				);

			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'jquery.chained' );
			wp_enqueue_script( OKTO_DEPO_PREFIX . 'main' );
			wp_enqueue_style(  OKTO_DEPO_PREFIX . 'main' );

			wp_localize_script( OKTO_DEPO_PREFIX . 'main', 'depo_sk', $data );
		}

		public function custom_bulk_admin_footer() {
			global $post_type;

			if($post_type == 'shop_order') {
			
				$plugin_url = admin_url( 'options-general.php?page=' . $this->id );
				?>
				<script type="text/javascript">

					function downloadAll(urls) {
					  var link = document.createElement('a');

					  link.setAttribute('download', null);
					  link.style.display = 'none';

					  document.body.appendChild(link);

					  for (var i = 0; i < urls.length; i++) {
					    link.setAttribute('href', urls[i]);
					    link.click();
					  }

					  document.body.removeChild(link);
					}

					jQuery(document).ready(function() {
						jQuery('<option>').val('<?php echo $this->bulk_id; ?>').text('<?php _e('Depo.sk: tlačiť štítky')?>').appendTo("select[name='action'],select[name='action2']");

						jQuery("select[name='action'],select[name='action2']").on('change', function(e) {

							if("<?php echo $this->bulk_id; ?>" == jQuery(this).val()) {

								var ids = [];
								jQuery('tr.type-shop_order input[id^="cb-select-"]:checked').each(function( ) {

									ids.push("<?php echo $plugin_url; ?>&print_post_id=" + jQuery(this).val());

								});
								downloadAll(ids)						


							}

						});

					});
				</script>
				<?php
			}
		}

	}
	new depo_shipping_method_setup();
}