<?php

// http://admindev.depo.sk/apigility/documentation/Api-v1

require_once(  OKTO_DEPO_INC_PATH . 'functions.php' );

class Depo {

	use Functions;

	public $timeout = 10;
	public $agent;

	public $username;
	public $password;
	public $size;
	public $enviroment;
	public $url;
	public $iframeUrl;
	public $client;
	public $debug;
	public $cod;
	// public $insurance;
	private $placesFileName;
	private $placesInterval;

	public function __construct( $settings ) {


		$this->client     = $settings['client'];
		$this->username   = $settings['username'];
		$this->password   = $settings['password'];
		$this->size       = $settings['size'];
		$this->enviroment = $settings['enviroment'];
		$this->debug      = $settings['debug'];
		$this->cod        = $settings['cod'];
		// $this->insurance = $insurance;
		$this->placesFileName = OKTO_DEPO_PATH . 'output-places.txt'; // temp db
		$this->placesInterval = 86400; // 1 day in s

		if($this->enviroment == 'production') {
			$this->url       = 'https://admin.depo.sk/v1/api/';
			$this->iframeUrl = 'https://admin.depo.sk/eshop';
		} else { // development
			$this->url       = 'https://admindev.depo.sk/v1/api/';
			$this->iframeUrl = 'https://admindev.depo.sk/eshop';		
		}

		$this->agent = 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 1.0.3705; .NET CLR 1.1.4322) Wordpress Module okto';

	}

	public function getIframe( $order_id, $width = '100%', $height = '610') {
		return '<div id="okto-depo-iframe" class="okto-hidden-xs"><iframe frameBorder="0" src="'.$this->iframeUrl.'?c='.$this->client.'&amp;o='.$order_id.'" width="'.$width.'" height="'.$height.'"></iframe></div>';
	}


	public function load_new_places() {

		$response = $this->places();
		$places   = [];
		if(isset($response->_embedded->places)) {
			foreach($response->_embedded->places as $place) {
				if($place->is_output <> 1) continue;
				$places[] = $place;
			}
		}

		$places = serialize($places);

		file_put_contents($this->placesFileName, $places);
	}

	public function get_places_from_file() {

		if(!file_exists($this->placesFileName)) {
			$this->load_new_places();
		}

		// ak je starsi ako den tak nacita nanovo
		if(filemtime($this->placesFileName) <= ( time() - $this->placesInterval ) ) {
			$this->load_new_places();
		}

		$places = @file_get_contents($this->placesFileName);
		$places = unserialize($places);

		if($places and sizeof($places) > 0)
			return $places;

		return [];
	}

	public function generate_dropdown_with_places( $city = false, $pickup = false ) {

		$places = $this->get_places_from_file();
		$out    = '';
		$mesto  = [];

		foreach($places as $place) {
			$mesto[$place->city][$place->street][$place->name] = $place->id;
		}

		ksort($mesto);

		$out .= '<label class="okto-depo-label" for="okto-depo-mesto"><span class="okto-depo-numbers">1.</span> '.__('Prosím vyberte mesto', 'depo-sk').'</label>';
		$out .= '<select id="okto-depo-mesto" name="okto-depo-mesto"><option value="">--</option>';
		foreach($mesto as $key => $val) {
			$selected = ($this->toAscii($key) == $this->toAscii($city)) ? ' selected="selected" ' : '';
			$out .= '<option value="'.$this->toAscii($key).'" '.$selected.' >'.$key.'</option>';
		}
		$out .= '</select>';

		$out .= '<label class="okto-depo-label" for="okto-depo-pickup"><span class="okto-depo-numbers">2.</span> '.__('Výdajné miesto', 'depo-sk').'</label>';
		$out .= '<select id="okto-depo-pickup" name="okto-depo-pickup"><option value="">--</option>';

		foreach($mesto as $mesto_key => $mesto_val) {
			foreach($mesto_val as $street_key => $street_val) {
				foreach($street_val as $place_key => $place_val) {
					$selected = ($place_val == $pickup) ? ' selected="selected" ' : '';
					$out .= '<option  value="'.$place_val.'" class="'.$this->toAscii($mesto_key).'" '.$selected.'>'.$street_key . ' - ' . $place_key.'</option>';
				}
			}
		}
		
		$out .= '</select>';

		return $out;
	}

	public function show_dropdown_with_places( $return_element = false, $only_mobile = true ) {
		// spracovanie places

		$class = $only_mobile ? 'okto-visible-xs' : '';

		$out = '';
		$out .= '<div id="okto-depo-select" class="'.$class.'">';
		$out .= '<img id="okto-depo-select-img" src="http://admin.depo.sk/img/logo.png" width="100"/>';
		$out .= $this->generate_dropdown_with_places();
		$out .= '<div id="okto-depo-saved">';
		$out .= '<span class="dashicons dashicons-yes"></span> ';
		$out .= '<span>' . __('Výdajné miesto zvolené', 'depo-sk') . '</span>';
		$out .= '</div>';
		$out .= '</div>';

		if($return_element)
			return $out;

		echo $out;
	}

	public function curl( $url, $attr = [] ) {

		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_USERAGENT, $this->agent);
		curl_setopt($ch, CURLOPT_VERBOSE, false); // is it printing in CLI? for debugging purposes only
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $this->timeout);

		$headers  =  array( 
			"Accept: application/json", 
			"Content-Type: application/json"
		);
		curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

		// are post attributes set?
		if(!empty($attr)) {
			$postFields = json_encode($attr);

			curl_setopt($ch, CURLOPT_POST, 1);
			curl_setopt($ch, CURLOPT_POSTFIELDS, $postFields);
		}

		$this->debug($attr, "==== REQUEST " . date('d.m.Y H:i:s') . " | ". $url . "\n");

		curl_setopt($ch, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
		curl_setopt($ch, CURLOPT_USERPWD, $this->username . ":" . $this->password);  
		$result = curl_exec($ch);
		curl_close($ch);

		// ignorovat PDF z metody label
		$ignore_result = [$this->url . 'packages/label'];
		if(!in_array($url, $ignore_result))
			$this->debug($result, "==== RESPONSE\n", "\n==== END\n\n");
		
		return $result;
	}

	// http://admindev.depo.sk/v1/api/places[/:id] (get)
	public function place( $id ) {
		$url = $this->url . 'places/' . $id;
		$response = $this->curl( $url );
		// return $response;
		return $this->parse( $response );
	}

	// http://admindev.depo.sk/v1/api/places (get)
	public function places( ) {
		$url = $this->url . 'places';
		$response = $this->curl( $url );
		// return $response;
		return $this->parse( $response );
	}

	// Vráti zoznam všetkých zásielok registrovaných k prihlásenému kontu.
	// http://admindev.depo.sk/v1/api/packages (get)
	public function packages( ) {
		$url = $this->url . 'packages';
		$response = $this->curl( $url );
		return $this->parse( $response );
	}

	// http://admindev.depo.sk/v1/api/packages[/:id] (get)
	public function package( $id ) {
		$url = $this->url . 'packages/'.$id;
		$response = $this->curl( $url );
		return $this->parse( $response );
	}

	// Metóda na registráciu novej zásielky
	// http://admindev.depo.sk/v1/api/packages/send (post)
	public function send( $order_id, $address_id, $override_18 = null, $override_cod = null ) {

		$url      = $this->url . 'packages/send';
		$data     = [];

		$order = new WC_Order($order_id);

		// target	Id výdajného miesta pre zásielku (id pochádza z API metódy places) ÁNO
		$data['target']            = $address_id;
		// recipient_name	Meno a priezvisko príjemcu zásielky ÁNO
		$data['recipient_name']    = $order->shipping_first_name . ' ' . $order->shipping_last_name;
		// recipient_street	Ulica príjemcu zásielky (nepovinné) NIE
		$data['recipient_street']  = $order->shipping_address_1;
		// recipient_zip	PSČ príjemcu zásielky (nepovinné) NIE
		$data['recipient_zip']     = $order->shipping_postcode;
		// recipient_city	Obec príjemcu zásielky (nepovinné) NIE
		$data['recipient_city']    = $order->shipping_city;
		// recipient_country	Krajina príjemcu zásielky (nepovinné) NIE
		$data['recipient_country'] = $order->shipping_country;
		// recipient_phone	Mobilné telefónne číslo príjemcu zásielky v medzinárodnom tvare bez medzier a bez znaku +. Povolené sú len číslice. ÁNO
		$data['recipient_phone']   = $this->makePhoneGreatAgain( $order->billing_phone );
		// recipient_email	E-mailová adresa príjemcu zásielky ÁNO
		$data['recipient_email']   = $order->billing_email;
		// cod	Suma dobierky v EUR NIE

		// interne referencne ID cislo (cislo objednavky)
		$data['sender_reference']  = $order->id;

		
		// vykonat kontrolu ci ma kupujuci aspon 18 rokov / ak ma aspon jeden produkt +18 tak nastavi na true
		if($override_18 !== null) {
			$check18 = ($override_18 == true) ? 1 : 0;
		} else {
			$check18 = 0;
			foreach($order->get_items() as $item) {
				if( get_post_meta( $item['product_id'], '_depo_18years_check', true) == 'yes') {
					$check18 = 1;
					break;
				}
			}
		}


		$data['service_18plus']  = $check18;
		
		// priradit k objednavke parameter
		update_post_meta( $order->id, '_depo_18years_check', ($check18) ? 'yes' : 'no' );

		// ak je dobierka
		if(in_array($order->payment_method, $this->cod)) {
			$data['cod'] = $order->order_total;
		}

		// override dobierky
		if($override_cod !== null) {
			if($override_cod) {
				$data['cod'] = $order->order_total;
			} else {
				unset($data['cod']);
			}
		}
 
		update_post_meta( $order->id, '_depo_cod', isset($data['cod']) ? 'yes' : 'no' );

/*
 
		// if ( $order->payment_method == 'bacs' || $order->payment_method == 'cod' || $order->payment_method == 'cheque'  ) 
		if($order->payment_method == 'cod') // quick fix
			$data['cod']           = $order->order_total; // TODO zistit ci je uz zaplatene if cod = order total else 0
		// insurance	Hodnota zásielky v EUR ÁNO
*/
		$data['insurance']         = $order->order_total; // number_format( (float) $this->insurance, 2, '.', '' );

		// size_a	Rozmer zásielky a (v centimetroch, nepovinné) NIE
		// size_b	Rozmer zásielky b (v centimetroch, nepovinné) NIE
		// size_c	Rozmer zásielky c (v centimetroch, nepovinné) NIE
		// weight	Hmotnosť zásielky (v gramoch, nepovinné) NIE

		$response = $this->curl( $url, $data );


		return $this->parse( $response );
	}

	// http://admindev.depo.sk/v1/api/packages/cancel (post)
	public function cancel( $order_id ) {
		$url      = $this->url . 'packages/cancel';
		$data     = ['number' => $order_id];
		$response = $this->curl( $url, $data );
		$response = $this->parse( $response );
		return (isset($response->number) and $response->number == $order_id);
	}

	// Metóda na generovanie PDF dokumentu s generovaným štítkom pre zásielku.
	// http://admindev.depo.sk/v1/api/packages/label (post)
	public function label( $order_id, $position = 0 ) {
		$url      = $this->url . 'packages/label';
		$data     = [];
		// size	Počet štítkov na hárok A4 (3x5|2x2) ÁNO
		$data['size'] = $this->size;
		// number	Číslo zásielky ÁNO
		// $order_id = explode(',', $order_id);
		// if(is_array( $order_id) and sizeof($order_id) > 1 ) {
		// 	$i = 0;
		// 	foreach($order_id as $id) {
		// 		$data['number'][] = $id;

		// 		$i++;
		// 	}
		// } else {
		// 	$order_id = array_shift($order_id);
			$data['number'] = $order_id;
		// }

			$data['position'] = $position;

		// position	Umiestnenie generovaného štítku na hárku, číslovanie do riadkov začínajúce od 0. NIE
		// includeLines	0/1 Informácia, či majú byť generované oddelujúce línie NIE
		// var_dump($data);
		// die;
		$response = $this->curl( $url, $data );
		return $response;
	}

	// Metóda na zistenie zvoleného výdajného miesta zákazníkom
	// http://admindev.depo.sk/v1/api/places/` (post)
	public function selected( $order = null ) {
		$url      = $this->url . 'places/selected';
		$data     = ['order' => $order];
		$response = $this->curl( $url, $data );

		return $this->parse( $response );
	}

	public function parse( $input ) {
		$input = '['.(string)$input.']';
		$array = json_decode($input);
		return array_shift( $array );
	}

}